@@ -1,19 +1,19 @@
 #' An alternative to sessionInfo() to print session information
 #'
-#' This function tweaks the output of \code{\link{sessionInfo}()}: (1) It adds
+#' This function tweaks the output of [sessionInfo()]: (1) It adds
 #' the RStudio version information if running in the RStudio IDE; (2) It removes
 #' the information about matrix products, BLAS, and LAPACK; (3) It removes the
 #' names of base R packages; (4) It prints out package versions in a single
 #' group, and does not differentiate between loaded and attached packages.
 #'
 #' It also allows you to only print out the versions of specified packages (via
-#' the \code{packages} argument) and optionally their recursive dependencies.
+#' the `packages` argument) and optionally their recursive dependencies.
 #' For these specified packages (if provided), if a function
-#' \code{xfun_session_info()} exists in a package, it will be called and
+#' `xfun_session_info()` exists in a package, it will be called and
 #' expected to return a character vector to be appended to the output of
-#' \code{session_info()}. This provides a mechanism for other packages to inject
-#' more information into the \code{session_info} output. For example,
-#' \pkg{rmarkdown} (>= 1.20.2) has a function \code{xfun_session_info()} that
+#' `session_info()`. This provides a mechanism for other packages to inject
+#' more information into the `session_info` output. For example,
+#' \pkg{rmarkdown} (>= 1.20.2) has a function `xfun_session_info()` that
 #' returns the version of Pandoc, which can be very useful information for
 #' diagnostics.
 #' @param packages A character vector of package names, of which the versions
@@ -22,7 +22,7 @@
 #' @param dependencies Whether to print out the versions of the recursive
 #'   dependencies of packages.
 #' @return A character vector of the session information marked as
-#'   \code{\link{raw_string}()}.
+#'   [raw_string()].
 #' @export
 #' @examplesIf interactive()
 #' xfun::session_info()
@@ -83,16 +83,16 @@ session_info = function(packages = NULL, dependencies = TRUE) {
 #' Perform a task once in an R session, e.g., emit a message or warning. Then
 #' give users an optional hint on how not to perform this task at all.
 #' @param task Any R code expression to be evaluated once to perform a task,
-#'   e.g., \code{warning('Danger!')} or \code{message('Today is ', Sys.Date())}.
+#'   e.g., `warning('Danger!')` or `message('Today is ', Sys.Date())`.
 #' @param option An R option name. This name should be as unique as possible in
-#'   \code{\link{options}()}. After the task has been successfully performed,
-#'   this option will be set to \code{FALSE} in the current R session, to
+#'   [options()]. After the task has been successfully performed,
+#'   this option will be set to `FALSE` in the current R session, to
 #'   prevent the task from being performed again the next time when
-#'   \code{do_once()} is called.
+#'   `do_once()` is called.
 #' @param hint A character vector to provide a hint to users on how not to
 #'   perform the task or see the message again in the current R session. Set
-#'   \code{hint = ""} if you do not want to provide the hint.
-#' @return The value returned by the \code{task}, invisibly.
+#'   `hint = ""` if you do not want to provide the hint.
+#' @return The value returned by the `task`, invisibly.
 #' @export
 #' @examples
 #' do_once(message("Today's date is ", Sys.Date()), "xfun.date.reminder")
@@ -106,7 +106,7 @@ do_once = function(task, option, hint = c(
   'If you never want to see this message,',
   sprintf('you may set options(%s = FALSE) in your .Rprofile.', option)
 )) {
-  if (isFALSE(getOption(option))) return(invisible())
+  if (identical(getOption(option), FALSE)) return(invisible())
   task
   hint = paste(hint, collapse = ' ')
   if (hint != '') message(hint)
